PyXMake Developer Guide: PyXMake.Build.Make.Doxygen Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.Doxygen Class Reference

Base class for all Doxygen build events. More...

Inheritance diagram for PyXMake.Build.Make.Doxygen:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| Settings (self, brief, header, outdir='', **kwargs)
| parse (cls, **kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
| __posix__ (self, **kwargs)
| AddIncludePath (self, includes)
| AddDependencyPath (self, dependencies)
| UseLibraries (self, libs)
| SourcePath (self, path)
| OutputPath (self, path, files="")
| Environment (self, path, script="ifortvars.bat")
| Preprocessing (self, cmdstring='', inend='', outend='', copyfiles=[], replace={'!DEC$ IF':'#IF','!DEC$ ELSE':'#ELSE','!DEC$ ENDIF':'#ENDIF'})
| Build (self, cmdstring, **kwargs)
| Postprocessing (self, cmdstring='')
| run (cls, **kwargs)
| create (self, **kwargs)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
str | MakeObjectKind = 'Doxygen'
| String identifier of current instance.
| path2exe = os.path.join(PyXMakePath,"Build","bin","doxygen")
| Path to Doxygen executable.
str | exe = 'doxygen.exe'
| Executable of Doxygen.
str | stype = 'Fortran':
| Type of source file.
str | buildname = self.buildid+"_doc.f90"
| Temporary build name of current job.
| temps = self.temps + (self.buildname, )
| Tuple of temporary files scheduled for removal.
list | temps = " "
| srcs = ''
| postcmd = delimn.join(rev_command)
list | incdirs = []
| Blank version of list containing library directories without initially specifying MKL.
list | libdirs = []
| outdir = outdir
| Output directory of current job.
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid = BuildID
| Base string of build object.
list | srcs = []
| Source file or folders.
list | bare = not BuildID and not self.srcs
| stype = kwargs.get("stype",'Fortran')
| Source file type.
| verbose = verbose
| Level of verbosity of the current build object.
| hasFoss = kwargs.get("foss", Utility.GetExecutable("choco") or Utility.GetPlatform() in ["linux"] or kwargs.get("bash",False))
| Toggle between free open source software and commercial 3rd party libraries.
| scrtdir = os.getcwd()
| Current scratch directory
| srcdir = os.getcwd()
| Default search directory for source files.
| outdir = os.getcwd()
| Default search directory for output.
_, self.intelpath, self.iniCompiler | intelpath = content
| Path to Intel Fortran Compiler (read from Paths.log or empty).
tuple | temps = ()
| Tuple of data to be removed after job completion.
list | incdirs = []
| List of include directories.
list | libdirs = []
| List of library directories.
list | libs = []
| List of actual libraries (by name) used during linking.
list | copyfiles = []
| List of files to be copied to the output directory after finish.
str | iniCompiler = ""
| Default initialization of compiler script.
bool | setarch = True if kwargs.get('arch', None) in ['x86', 'x64'] else False
| Define the architecture for the build directly by using the keyword argument "arch".
| msvsc = kwargs.get("msvsc",'vs2015')
| Default version of Microsoft visual studio used by the Intel Fortran Compiler.
str | architecture = 'x86'
| Processor architecture.
str | postcmd = ""
| Post build command.
| buildname = self.temps + (inputfile, )
str | precmd = self.iniCompiler+" "+cmdstring
| Command executed during pre-build event.
| compargs = cmdstring
| Command line arguments passed in by the user.
str | makecmd = self.iniCompiler+" "+os.path.join(self.path2exe,self.exe)+" "+ cmd + cmdstring
| Command executed during build event.
| mkl_dependency

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Build.Make.Make
| __parser__ ()
| Detach ()
| F2CPreprocessing (PreprocessingFile)
| sanitize (string, **kwargs)
| setup (*args, **kwargs)
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)
Protected Attributes inherited from PyXMake.Build.Make.Make
list | _mkl_includes = [x for x in self.incdirs if "mkl" in x]

## Detailed Description

Base class for all Doxygen build events.

    Inherited class to automatically build a documentation using Doxygen.

Inherited from Make.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Build.Make.Doxygen.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of doxygen class object.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 2770 of file Make.py.

## Member Function Documentation

## ◆ parse()

PyXMake.Build.Make.Doxygen.parse | ( |  | cls,
|  | ** | kwargs )

    Execute the current class as a CLI command.

Definition at line 2928 of file Make.py.

## ◆ Settings()

PyXMake.Build.Make.Doxygen.Settings | ( |  | self,
|  |  | brief,
|  |  | header,
|  |  | outdir = '',
|  | ** | kwargs )

    Define environment variables for the default configuration file.

Definition at line 2890 of file Make.py.

## Member Data Documentation

## ◆ buildname

str PyXMake.Build.Make.Doxygen.buildname = self.buildid+"_doc.f90"

Temporary build name of current job.

Definition at line 2809 of file Make.py.

## ◆ exe

PyXMake.Build.Make.Doxygen.exe = 'doxygen.exe'

Executable of Doxygen.

Update configuration file to the latest Doxygen syntax by default.

Do not issue a warning (for now!)

Definition at line 2787 of file Make.py.

## ◆ incdirs

list PyXMake.Build.Make.Doxygen.incdirs = []

Blank version of list containing library directories without initially specifying MKL.

Definition at line 2886 of file Make.py.

## ◆ libdirs

list PyXMake.Build.Make.Doxygen.libdirs = []

Definition at line 2887 of file Make.py.

## ◆ MakeObjectKind

str PyXMake.Build.Make.Doxygen.MakeObjectKind = 'Doxygen'

String identifier of current instance.

Definition at line 2776 of file Make.py.

## ◆ outdir

PyXMake.Build.Make.Doxygen.outdir = outdir

Output directory of current job.

Defaults to current workspace if not given.

Definition at line 2897 of file Make.py.

## ◆ path2exe

PyXMake.Build.Make.Doxygen.path2exe = os.path.join(PyXMakePath,"Build","bin","doxygen")

Path to Doxygen executable.

Update configuration file to the latest Doxygen syntax by default.

Do not issue a warning (for now!)

Definition at line 2785 of file Make.py.

## ◆ postcmd

PyXMake.Build.Make.Doxygen.postcmd = delimn.join(rev_command)

Definition at line 2862 of file Make.py.

## ◆ srcs

PyXMake.Build.Make.Doxygen.srcs = ''

Definition at line 2819 of file Make.py.

## ◆ stype

str PyXMake.Build.Make.Doxygen.stype = 'Fortran':

Type of source file.

Can be one of Fortran, CCpp or Other. Defaults to Fortran if not specified. Starts documentation procedure for Java/Python if type is neither Fortran nor CCpp.

Definition at line 2806 of file Make.py.

## ◆ temps [1/2]

PyXMake.Build.Make.Doxygen.temps = self.temps + (self.buildname, )

Tuple of temporary files scheduled for removal.

Definition at line 2811 of file Make.py.

## ◆ temps [2/2]

list PyXMake.Build.Make.Doxygen.temps = " "

Definition at line 2815 of file Make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Build/Make.py